==> angelssmelting_0.6.14.zip: angelssmelting_0.6.14/prototypes/items/angels-chrome.lua <==
data:extend(
{
  --ORE
  {
    type = "item",
    name = "chrome-ore",
    icon = "__angelssmelting__/graphics/icons/ore-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "a",
    stack_size = 200
  },
  -- SMELTING INTERMEDIATE
  {
    type = "item",
    name = "processed-chrome",
    icon = "__angelssmelting__/graphics/icons/processed-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-chrome",
    icon = "__angelssmelting__/graphics/icons/pellet-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chromate",
    icon = "__angelssmelting__/graphics/icons/solid-chromate.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-dichromate",
    icon = "__angelssmelting__/graphics/icons/solid-dichromate.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chrome-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-chrome-oxide.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "f",
    stack_size = 200
  },
  -- SMELTING RESULTS
  {
    type = "item",
    name = "ingot-chrome",
    icon = "__angelssmelting__/graphics/icons/ingot-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "g",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-chrome",
    icon = "__angelssmelting__/graphics/icons/powder-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "h",
    stack_size = 200
  },
  -- CASTING INTERMEDIATE
  {
    type = "fluid",
    name = "liquid-molten-chrome",
    icon = "__angelssmelting__/graphics/icons/molten-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome-casting",
    order = "i",
    default_temperature = 1907,
    heat_capacity = "0KJ",
    base_color = {r = 200/255, g = 186/255, b = 245/255},
    flow_color = {r = 200/255, g = 186/255, b = 245/255},
    max_temperature = 1907,
    pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
    auto_barrel = false
  },
  {
    type = "item",
    name = "angels-roll-chrome",
    icon = "__angelssmelting__/graphics/icons/roll-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome-casting",
    order = "j",
    stack_size = 200
  },
  -- CASTING RESULT
  {
    type = "item",
    name = "angels-plate-chrome",
    icon = "__angelssmelting__/graphics/icons/plate-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome-casting",
    order = "k",
    stack_size = 200
  },
}
)

==> angelssmelting_0.6.16.zip: angelssmelting_0.6.16/prototypes/items/angels-chrome.lua <==
data:extend(
{
  --ORE
  {
    type = "item",
    name = "chrome-ore",
    icon = "__angelssmelting__/graphics/icons/ore-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "a",
    stack_size = 200
  },
  -- SMELTING INTERMEDIATE
  {
    type = "item",
    name = "processed-chrome",
    icon = "__angelssmelting__/graphics/icons/processed-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-chrome",
    icon = "__angelssmelting__/graphics/icons/pellet-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chromate",
    icon = "__angelssmelting__/graphics/icons/solid-chromate.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-dichromate",
    icon = "__angelssmelting__/graphics/icons/solid-dichromate.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chrome-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-chrome-oxide.png",
    icon_size = 32,
    subgroup = "angels-chrome",
    order = "f",
    stack_size = 200
  },
  -- SMELTING RESULTS
  {
    type = "item",
    name = "ingot-chrome",
    icon = "__angelssmelting__/graphics/icons/ingot-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome",
    order = "g",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-chrome",
    icon = "__angelssmelting__/graphics/icons/powder-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome",
    order = "h",
    stack_size = 200
  },
  -- CASTING INTERMEDIATE
  {
    type = "fluid",
    name = "liquid-molten-chrome",
    icon = "__angelssmelting__/graphics/icons/molten-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome-casting",
    order = "i",
    default_temperature = 1907,
    heat_capacity = "0KJ",
    base_color = {r = 200/255, g = 186/255, b = 245/255},
    flow_color = {r = 200/255, g = 186/255, b = 245/255},
    max_temperature = 1907,
    pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
    auto_barrel = false
  },
  {
    type = "item",
    name = "angels-roll-chrome",
    icon = "__angelssmelting__/graphics/icons/roll-chrome.png",
    icon_size = 64, icon_mipmaps = 4,
    subgroup = "angels-chrome-casting",
    order = "j",
    stack_size = 200
  },
  -- CASTING RESULT
  {
    type = "item",
    name = "angels-plate-chrome",
    icon = "__angelssmelting__/graphics/icons/plate-chrome.png",
    icon_size = 32,
    subgroup = "angels-chrome-casting",
    order = "k",
    stack_size = 200
  },
}
)
